@@ -101,6 +101,7 @@ static const char * const ephy_prefs_state_schema[] = {
 #define EPHY_PREFS_WEB_ENABLE_SITE_SPECIFIC_QUIRKS "enable-site-specific-quirks"
 #define EPHY_PREFS_WEB_ENABLE_SAFE_BROWSING        "enable-safe-browsing"
 #define EPHY_PREFS_WEB_GSB_API_KEY                 "gsb-api-key"
+#define EPHY_PREFS_WEB_DEFAULT_ZOOM_LEVEL          "default-zoom-level"
 
 static const char * const ephy_prefs_web_schema[] = {
   EPHY_PREFS_WEB_FONT_MIN_SIZE,
@@ -124,14 +125,14 @@ static const char * const ephy_prefs_web_schema[] = {
   EPHY_PREFS_WEB_REMEMBER_PASSWORDS,
   EPHY_PREFS_WEB_ENABLE_SITE_SPECIFIC_QUIRKS,
   EPHY_PREFS_WEB_ENABLE_SAFE_BROWSING,
-  EPHY_PREFS_WEB_GSB_API_KEY
+  EPHY_PREFS_WEB_GSB_API_KEY,
+  EPHY_PREFS_WEB_DEFAULT_ZOOM_LEVEL
 };
 
 #define EPHY_PREFS_SCHEMA                             "org.gnome.Epiphany"
 #define EPHY_PREFS_HOMEPAGE_URL                       "homepage-url"
 #define EPHY_PREFS_DEPRECATED_USER_AGENT              "user-agent"
 #define EPHY_PREFS_NEW_WINDOWS_IN_TABS                "new-windows-in-tabs"
-#define EPHY_PREFS_AUTO_DOWNLOADS                     "automatic-downloads"
 #define EPHY_PREFS_WARN_ON_CLOSE_UNSUBMITTED_DATA     "warn-on-close-unsubmitted-data"
 #define EPHY_PREFS_DEPRECATED_REMEMBER_PASSWORDS      "remember-passwords"
 #define EPHY_PREFS_KEYWORD_SEARCH_URL                 "keyword-search-url"
